BTreeGraph

Struct BTreeGraph 

pub struct BTreeGraph<R> { /* private fields */ }
BTree-based RDF graph holding a uniform resource handle type R.

Implementations

Source

impl<R> BTreeGraph<R>

pub fn new() -> Self

Creates a new empty graph.

pub fn len(&self) -> usize

Returns the number of triples in the graph.

pub fn is_empty(&self) -> bool

Checks if the graph is empty.

Source

impl<R: Resource> BTreeGraph<R>

pub fn iter(&self) -> Triples<'_, R>

Returns an iterator over the triples of the graph.

pub fn resources(&self) -> Resources<'_, R>

Returns an iterator over the resources of the graph.

pub fn into_indexed(self) -> IndexedBTreeGraph<R>

Indexes the triples to allow more operation on this graph, such as pattern matching using the PatternMatchingGraph trait.

Source

impl<R: Resource + Ord> BTreeGraph<R>

pub fn contains_resource(&self, resource: &R) -> bool

Checks if the provided resource appears in any triple in the graph.

pub fn contains(&self, triple: Triple<&R, &R, &R>) -> bool

Checks if the provided triple is in the graph.

pub fn insert(&mut self, triple: Triple<R, R, R>) -> bool

Inserts the given triple in the graph.

Returns true if the triple was not already in the graph, and false if it was.

pub fn remove(&mut self, triple: Triple<&R, &R, &R>) -> bool

Removes the given triple from the graph.

Returns whether or not the triple was in the graph. Does nothing if the triple was not in the graph.

Source

impl<R: Resource + Clone + Ord> BTreeGraph<R>

pub fn absorb<I: IntoIterator<Item = Triple<R, R, R>>>(&mut self, iter: I)

Inserts every triple of iter in the graph.