pub struct DatasetGraphView<'a, D: Dataset> {
pub dataset: &'a D,
pub graph: Option<&'a D::Subject>,
pub resource: &'a D::Subject,
}Expand description
Dataset view focusing on a given resource and restricted to the given graph.
Fields
dataset: &'a DThe dataset being viewed.
graph: Option<&'a D::Subject>Name of the graph in focus, None for the default graph.
resource: &'a D::SubjectThe resource in focus.