impl_resource

Macro impl_resource 

macro_rules! impl_resource {
    ($t:ty) => { ... };
}
Implements Resource and the four position traits for a type, granting it eligibility in every position of a triple/quad.