pub enum AnySubject<T> {
AnyPredicate(AnySubjectAnyPredicate<T>),
SameAsSubject(AnySubjectGivenPredicate<T>),
GivenPredicate(T, AnySubjectGivenPredicate<T>),
}Expand description
Canonical quad pattern matching any subject.
Variants
AnyPredicate(AnySubjectAnyPredicate<T>)
Any predicate.
SameAsSubject(AnySubjectGivenPredicate<T>)
A predicate equal to the subject.
GivenPredicate(T, AnySubjectGivenPredicate<T>)
A given predicate.
Implementations
Sourceimpl<T> AnySubject<T>
impl<T> AnySubject<T>
Sourcepub fn from_option_quad(
p: Option<T>,
o: Option<T>,
g: Option<Option<T>>,
) -> Self
pub fn from_option_quad( p: Option<T>, o: Option<T>, g: Option<Option<T>>, ) -> Self
Builds a pattern from a quad whose unset positions match anything.
Sourcepub fn from_pattern<X: PartialEq>(
s: X,
p: ResourceOrVar<T, X>,
o: ResourceOrVar<T, X>,
g: Option<ResourceOrVar<T, X>>,
) -> Self
pub fn from_pattern<X: PartialEq>( s: X, p: ResourceOrVar<T, X>, o: ResourceOrVar<T, X>, g: Option<ResourceOrVar<T, X>>, ) -> Self
Builds a pattern from pattern, canonicalizing repeated
variables into SameAs positions.
Sourcepub const fn predicate(&self) -> PatternPredicate<&T>
pub const fn predicate(&self) -> PatternPredicate<&T>
Returns the predicate of this pattern.
Sourcepub fn into_predicate(self) -> PatternPredicate<T>
pub fn into_predicate(self) -> PatternPredicate<T>
Consumes this pattern, returning its predicate.
Sourcepub const fn object(&self) -> PatternObject<&T>
pub const fn object(&self) -> PatternObject<&T>
Returns the object of this pattern.
Sourcepub fn into_object(self) -> PatternObject<T>
pub fn into_object(self) -> PatternObject<T>
Consumes this pattern, returning its object.
Sourcepub const fn graph(&self) -> PatternGraph<&T>
pub const fn graph(&self) -> PatternGraph<&T>
Returns the graph of this pattern.
Sourcepub fn into_graph(self) -> PatternGraph<T>
pub fn into_graph(self) -> PatternGraph<T>
Consumes this pattern, returning its graph.
Sourcepub const fn as_ref(&self) -> AnySubject<&T>
pub const fn as_ref(&self) -> AnySubject<&T>
Borrows the resources of this pattern.
Sourcepub fn map<U>(self, f: impl FnMut(T) -> U) -> AnySubject<U>
pub fn map<U>(self, f: impl FnMut(T) -> U) -> AnySubject<U>
Maps the resources of this pattern with f.
Sourcepub fn map2<U, V>(
self,
f: impl FnMut(T) -> (U, V),
) -> (AnySubject<U>, AnySubject<V>)
pub fn map2<U, V>( self, f: impl FnMut(T) -> (U, V), ) -> (AnySubject<U>, AnySubject<V>)
Maps each resource to a pair with f, splitting this pattern in two.
Sourcepub fn into_triple(self) -> (AnySubject<T>, PatternGraph<T>)
pub fn into_triple(self) -> (AnySubject<T>, PatternGraph<T>)
Splits this quad pattern into a triple pattern and a graph pattern.
Sourcepub fn into_parts(
self,
) -> (PatternPredicate<T>, PatternObject<T>, PatternGraph<T>)
pub fn into_parts( self, ) -> (PatternPredicate<T>, PatternObject<T>, PatternGraph<T>)
Consumes this pattern, returning each position separately.