AnySubjectAnyPredicate

Enum AnySubjectAnyPredicate 

pub enum AnySubjectAnyPredicate<T> {
    AnyObject(AnySubjectAnyPredicateAnyObject<T>),
    SameAsSubject(AnySubjectAnyPredicateGivenObject<T>),
    SameAsPredicate(AnySubjectAnyPredicateGivenObject<T>),
    GivenObject(T, AnySubjectAnyPredicateGivenObject<T>),
}
Canonical quad pattern matching any subject, any predicate.

Variants



AnyObject(AnySubjectAnyPredicateAnyObject<T>)

Any object.



SameAsSubject(AnySubjectAnyPredicateGivenObject<T>)

A object equal to the subject.



SameAsPredicate(AnySubjectAnyPredicateGivenObject<T>)

A object equal to the predicate.



GivenObject(T, AnySubjectAnyPredicateGivenObject<T>)

A given object.

Implementations

Source

impl<T> AnySubjectAnyPredicate<T>

pub fn from_option(o: Option<T>, g: Option<Option<T>>) -> Self

Builds a pattern whose unset positions match anything.

pub fn from_pattern<X: PartialEq>( s: X, p: X, o: ResourceOrVar<T, X>, g: Option<ResourceOrVar<T, X>>, ) -> Self

Builds a pattern from pattern, canonicalizing repeated variables into SameAs positions.

pub const fn object(&self) -> PatternObject<&T>

Returns the object of this pattern.

pub fn into_object(self) -> PatternObject<T>

Consumes this pattern, returning its object.

pub const fn graph(&self) -> PatternGraph<&T>

Returns the graph of this pattern.

pub fn into_graph(self) -> PatternGraph<T>

Consumes this pattern, returning its graph.

pub const fn as_ref(&self) -> AnySubjectAnyPredicate<&T>

Borrows the resources of this pattern.

pub fn map<U>(self, f: impl FnMut(T) -> U) -> AnySubjectAnyPredicate<U>

Maps the resources of this pattern with f.

pub fn map2<U, V>( self, f: impl FnMut(T) -> (U, V), ) -> (AnySubjectAnyPredicate<U>, AnySubjectAnyPredicate<V>)

Maps each resource to a pair with f, splitting this pattern in two.

pub fn into_triple(self) -> (AnySubjectAnyPredicate<T>, PatternGraph<T>)

Splits this quad pattern into a triple pattern and a graph pattern.

pub fn into_parts(self) -> (PatternObject<T>, PatternGraph<T>)

Consumes this pattern, returning each position separately.