CanonicalQuadPattern

Enum CanonicalQuadPattern 

pub enum CanonicalQuadPattern<T> {
    AnySubject(AnySubject<T>),
    GivenSubject(T, GivenSubject<T>),
}
Canonical triple pattern.

Variants



AnySubject(AnySubject<T>)

Any subject.



GivenSubject(T, GivenSubject<T>)

A given subject.

Implementations

Source

impl<T: Resource> CanonicalQuadPattern<T>

pub fn from_triple(triple: Triple<T, T, T>) -> Self

Builds a pattern matching exactly triple, in any graph.

pub fn from_quad(quad: Quad<T, T, T, T>) -> Self

Builds a pattern matching exactly quad.

pub fn from_option_triple( triple: Triple<Option<T>, Option<T>, Option<T>>, ) -> Self

Builds a pattern from a triple whose unset positions match anything.

pub fn from_option_quad( quad: Quad<Option<T>, Option<T>, Option<T>, Option<T>>, ) -> Self

Builds a pattern from a quad whose unset positions match anything.

pub fn from_triple_pattern<X: PartialEq>(pattern: TriplePattern<T, X>) -> Self

Builds a pattern from a triple pattern, matching any graph.

pub fn from_pattern<X: PartialEq>(pattern: QuadPattern<T, X>) -> Self

Builds a pattern from pattern, canonicalizing repeated variables into SameAs positions.

Source

impl<T> CanonicalQuadPattern<T>

pub const fn subject(&self) -> PatternSubject<&T>

Returns the subject of this pattern.

pub fn into_subject(self) -> PatternSubject<T>

Consumes this pattern, returning its subject.

pub const fn predicate(&self) -> PatternPredicate<&T>

Returns the predicate of this pattern.

pub fn into_predicate(self) -> PatternPredicate<T>

Consumes this pattern, returning its predicate.

pub const fn object(&self) -> PatternObject<&T>

Returns the object of this pattern.

pub fn into_object(self) -> PatternObject<T>

Consumes this pattern, returning its object.

pub const fn graph(&self) -> PatternGraph<&T>

Returns the graph of this pattern.

pub fn into_graph(self) -> PatternGraph<T>

Consumes this pattern, returning its graph.

pub fn into_parts( self, ) -> (PatternSubject<T>, PatternPredicate<T>, PatternObject<T>, PatternGraph<T>)

Consumes this pattern, returning each position separately.

pub fn into_triple(self) -> (CanonicalTriplePattern<T>, PatternGraph<T>)

Splits this quad pattern into a triple pattern and a graph pattern.

pub const fn as_ref(&self) -> CanonicalQuadPattern<&T>

Borrows the resources of this pattern.

pub fn map<U>(self, f: impl FnMut(T) -> U) -> CanonicalQuadPattern<U>

Maps the resources of this pattern with f.

pub fn map2<U, V>( self, f: impl FnMut(T) -> (U, V), ) -> (CanonicalQuadPattern<U>, CanonicalQuadPattern<V>)

Maps each resource to a pair with f, splitting this pattern in two.