Quad

Struct Quad 

pub struct Quad<S: IsSubject = Id, P: IsPredicate = IriBuf, O: IsObject = LocalTerm, G: IsGraph = Id>(pub S, pub P, pub O, pub Option<G>);
RDF quad.

Position bounds enforce the RDF 1.1 / 1.2 abstract syntax: subjects must be IRIs or blank nodes, predicates must be IRIs, objects may be any term (including, in RDF 1.2, a triple term via LocalTerm::Triple), graph names must be IRIs or blank nodes. For generalized RDF (RDF 1.1 A / RDF 1.2 A.1) use GeneralizedQuad.

Tuple Fields

0: S1: P2: O3: Option<G>

Implementations

Source

impl<S: IsSubject, P: IsPredicate, O: IsObject, G: IsGraph> Quad<S, P, O, G>

pub const fn as_ref(&self) -> Quad<&S, &P, &O, &G>

Borrows each component of the quad.

Source

impl<S: IsSubject, P: IsPredicate, O: IsObject, G: IsGraph> Quad<&S, &P, &O, &G>

pub fn cloned(&self) -> Quad<S, P, O, G>
where S: Clone, P: Clone, O: Clone, G: Clone,

pub fn into_cloned(self) -> Quad<S, P, O, G>
where S: Clone, P: Clone, O: Clone, G: Clone,

Source

impl<S: IsSubject, P: IsPredicate, O: IsObject, G: IsGraph> Quad<&S, &P, &O, &G>

pub const fn copied(&self) -> Quad<S, P, O, G>
where S: Copy, P: Copy, O: Copy, G: Copy,

pub const fn into_copied(self) -> Quad<S, P, O, G>
where S: Copy, P: Copy, O: Copy, G: Copy,

Source

impl Quad

Source

impl Quad<IdRef<'_>, Iri<&str>, LocalTermRef<'_>, IdRef<'_>>

Source

impl<S: IsSubject, P: IsPredicate, O: IsObject, G: IsGraph> Quad<S, P, O, G>

pub const fn new(subject: S, predicate: P, object: O, graph: Option<G>) -> Self

Creates a new quad.

pub const fn subject(&self) -> &S

Returns a reference to the subject of the quad, the first component.

pub const fn subject_mut(&mut self) -> &mut S

Returns a mutable reference to the subject of the quad, the first component.

pub fn into_subject(self) -> S

Turns the quad into its subject, the first component.

pub const fn predicate(&self) -> &P

Returns a reference to the predicate of the quad, the second component.

pub const fn predicate_mut(&mut self) -> &mut P

Returns a mutable reference to the predicate of the quad, the second component.

pub fn into_predicate(self) -> P

Turns the quad into its predicate, the second component.

pub const fn object(&self) -> &O

Returns a reference to the object of the quad, the third component.

pub const fn object_mut(&mut self) -> &mut O

Returns a mutable reference to the object of the quad, the third component.

pub fn into_object(self) -> O

Turns the quad into its object, the third component.

pub const fn graph(&self) -> Option<&G>

Returns a reference to the graph of the quad, the fourth component.

pub const fn graph_mut(&mut self) -> Option<&mut G>

Returns a mutable reference to the graph of the quad, the fourth component.

pub fn into_graph(self) -> Option<G>

Turns the quad into its graph, the fourth component.

pub fn into_parts(self) -> (S, P, O, Option<G>)

pub fn into_triple(self) -> (Triple<S, P, O>, Option<G>)

Turns this quad into a triple and its graph component.

pub fn map_subject<U: IsSubject>( self, f: impl FnOnce(S) -> U, ) -> Quad<U, P, O, G>

Maps the subject with the given function.

pub fn map_predicate<U: IsPredicate>( self, f: impl FnOnce(P) -> U, ) -> Quad<S, U, O, G>

Maps the predicate with the given function.

pub fn map_object<U: IsObject>(self, f: impl FnOnce(O) -> U) -> Quad<S, P, U, G>

Maps the object with the given function.

pub fn map_graph<U: IsGraph>( self, f: impl FnOnce(Option<G>) -> Option<U>, ) -> Quad<S, P, O, U>

Maps the graph with the given function.

pub fn with_graph(self, g: Option<G>) -> Self

pub fn map_all<S2: IsSubject, P2: IsPredicate, O2: IsObject, G2: IsGraph>( self, s: impl FnOnce(S) -> S2, p: impl FnOnce(P) -> P2, o: impl FnOnce(O) -> O2, g: impl FnOnce(Option<G>) -> Option<G2>, ) -> Quad<S2, P2, O2, G2>

Maps every quad component with the given functions, one for each component.

Source

impl<T: IsSubject + IsPredicate + IsObject + IsGraph> Quad<T, T, T, T>

pub fn map<U: IsSubject + IsPredicate + IsObject + IsGraph>( self, f: impl FnMut(T) -> U, ) -> Quad<U, U, U, U>

Maps the components with the given function.

Source

impl<S, P, O, G> Quad<S, P, O, G>

pub fn strip_all_but_predicate( self, ) -> Quad<S::Stripped, P, O::Stripped, G::Stripped>

Strips metadata from subject, object, and graph, leaving the predicate untouched.