pub trait IsPredicate: Sealed { }Expand description
Types that may appear in the predicate position of an RDF triple/quad.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
pub trait IsPredicate: Sealed { }Types that may appear in the predicate position of an RDF triple/quad.
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".