pub struct BTreeGraph<R> { /* private fields */ }Expand description
BTree-based RDF graph holding a uniform resource handle type R.
Implementations
Sourceimpl<R> BTreeGraph<R>
impl<R> BTreeGraph<R>
Sourceimpl<R: Resource> BTreeGraph<R>
impl<R: Resource> BTreeGraph<R>
Sourcepub fn resources(&self) -> Resources<'_, R> ⓘ
pub fn resources(&self) -> Resources<'_, R> ⓘ
Returns an iterator over the resources of the graph.
Sourcepub fn into_indexed(self) -> IndexedBTreeGraph<R>
pub fn into_indexed(self) -> IndexedBTreeGraph<R>
Indexes the triples to allow more operation on this graph, such as
pattern matching using the PatternMatchingGraph trait.
Sourceimpl<R: Resource + Ord> BTreeGraph<R>
impl<R: Resource + Ord> BTreeGraph<R>
Sourcepub fn contains_resource(&self, resource: &R) -> bool
pub fn contains_resource(&self, resource: &R) -> bool
Checks if the provided resource appears in any triple in the graph.
Sourcepub fn contains(&self, triple: Triple<&R, &R, &R>) -> bool
pub fn contains(&self, triple: Triple<&R, &R, &R>) -> bool
Checks if the provided triple is in the graph.
Sourceimpl<R: Resource + Clone + Ord> BTreeGraph<R>
impl<R: Resource + Clone + Ord> BTreeGraph<R>
Sourcepub fn absorb<I: IntoIterator<Item = Triple<R, R, R>>>(&mut self, iter: I)
pub fn absorb<I: IntoIterator<Item = Triple<R, R, R>>>(&mut self, iter: I)
Inserts every triple of iter in the graph.