DatasetGraphView

Struct DatasetGraphView 

pub struct DatasetGraphView<'a, D: Dataset> {
    pub dataset: &'a D,
    pub graph: Option<&'a D::Subject>,
    pub resource: &'a D::Subject,
}
Dataset view focusing on a given resource and restricted to the given graph.

Fields

dataset: &'a D

The dataset being viewed.

graph: Option<&'a D::Subject>

Name of the graph in focus, None for the default graph.

resource: &'a D::Subject

The resource in focus.