pub struct Quad<S: IsSubject = Id, P: IsPredicate = IriBuf, O: IsObject = LocalTerm, G: IsGraph = Id>(pub S, pub P, pub O, pub Option<G>);Expand description
RDF quad.
Position bounds enforce the RDF 1.1 / 1.2 abstract syntax: subjects must
be IRIs or blank nodes, predicates must be IRIs, objects may be any term
(including, in RDF 1.2, a triple term via
LocalTerm::Triple), graph names must be IRIs
or blank nodes. For generalized RDF (RDF 1.1 A / RDF 1.2 A.1) use
GeneralizedQuad.
Tuple Fields
0: S1: P2: O3: Option<G>Implementations
Sourceimpl Quad
impl Quad
pub fn as_lexical_quad_ref(&self) -> LexicalQuadRef<'_>
Sourceimpl Quad<IdRef<'_>, Iri<&str>, LocalTermRef<'_>, IdRef<'_>>
impl Quad<IdRef<'_>, Iri<&str>, LocalTermRef<'_>, IdRef<'_>>
pub fn into_owned(self) -> LexicalQuad
Sourceimpl<S: IsSubject, P: IsPredicate, O: IsObject, G: IsGraph> Quad<S, P, O, G>
impl<S: IsSubject, P: IsPredicate, O: IsObject, G: IsGraph> Quad<S, P, O, G>
Sourcepub const fn new(subject: S, predicate: P, object: O, graph: Option<G>) -> Self
pub const fn new(subject: S, predicate: P, object: O, graph: Option<G>) -> Self
Creates a new quad.
Sourcepub const fn subject(&self) -> &S
pub const fn subject(&self) -> &S
Returns a reference to the subject of the quad, the first component.
Sourcepub const fn subject_mut(&mut self) -> &mut S
pub const fn subject_mut(&mut self) -> &mut S
Returns a mutable reference to the subject of the quad, the first component.
Sourcepub fn into_subject(self) -> S
pub fn into_subject(self) -> S
Turns the quad into its subject, the first component.
Sourcepub const fn predicate(&self) -> &P
pub const fn predicate(&self) -> &P
Returns a reference to the predicate of the quad, the second component.
Sourcepub const fn predicate_mut(&mut self) -> &mut P
pub const fn predicate_mut(&mut self) -> &mut P
Returns a mutable reference to the predicate of the quad, the second component.
Sourcepub fn into_predicate(self) -> P
pub fn into_predicate(self) -> P
Turns the quad into its predicate, the second component.
Sourcepub const fn object(&self) -> &O
pub const fn object(&self) -> &O
Returns a reference to the object of the quad, the third component.
Sourcepub const fn object_mut(&mut self) -> &mut O
pub const fn object_mut(&mut self) -> &mut O
Returns a mutable reference to the object of the quad, the third component.
Sourcepub fn into_object(self) -> O
pub fn into_object(self) -> O
Turns the quad into its object, the third component.
Sourcepub const fn graph(&self) -> Option<&G>
pub const fn graph(&self) -> Option<&G>
Returns a reference to the graph of the quad, the fourth component.
Sourcepub const fn graph_mut(&mut self) -> Option<&mut G>
pub const fn graph_mut(&mut self) -> Option<&mut G>
Returns a mutable reference to the graph of the quad, the fourth component.
Sourcepub fn into_graph(self) -> Option<G>
pub fn into_graph(self) -> Option<G>
Turns the quad into its graph, the fourth component.
pub fn into_parts(self) -> (S, P, O, Option<G>)
Sourcepub fn into_triple(self) -> (Triple<S, P, O>, Option<G>)
pub fn into_triple(self) -> (Triple<S, P, O>, Option<G>)
Turns this quad into a triple and its graph component.
Sourcepub fn map_subject<U: IsSubject>(
self,
f: impl FnOnce(S) -> U,
) -> Quad<U, P, O, G>
pub fn map_subject<U: IsSubject>( self, f: impl FnOnce(S) -> U, ) -> Quad<U, P, O, G>
Maps the subject with the given function.
Sourcepub fn map_predicate<U: IsPredicate>(
self,
f: impl FnOnce(P) -> U,
) -> Quad<S, U, O, G>
pub fn map_predicate<U: IsPredicate>( self, f: impl FnOnce(P) -> U, ) -> Quad<S, U, O, G>
Maps the predicate with the given function.
Sourcepub fn map_object<U: IsObject>(self, f: impl FnOnce(O) -> U) -> Quad<S, P, U, G>
pub fn map_object<U: IsObject>(self, f: impl FnOnce(O) -> U) -> Quad<S, P, U, G>
Maps the object with the given function.
Sourcepub fn map_graph<U: IsGraph>(
self,
f: impl FnOnce(Option<G>) -> Option<U>,
) -> Quad<S, P, O, U>
pub fn map_graph<U: IsGraph>( self, f: impl FnOnce(Option<G>) -> Option<U>, ) -> Quad<S, P, O, U>
Maps the graph with the given function.
pub fn with_graph(self, g: Option<G>) -> Self
Sourcepub fn map_all<S2: IsSubject, P2: IsPredicate, O2: IsObject, G2: IsGraph>(
self,
s: impl FnOnce(S) -> S2,
p: impl FnOnce(P) -> P2,
o: impl FnOnce(O) -> O2,
g: impl FnOnce(Option<G>) -> Option<G2>,
) -> Quad<S2, P2, O2, G2>
pub fn map_all<S2: IsSubject, P2: IsPredicate, O2: IsObject, G2: IsGraph>( self, s: impl FnOnce(S) -> S2, p: impl FnOnce(P) -> P2, o: impl FnOnce(O) -> O2, g: impl FnOnce(Option<G>) -> Option<G2>, ) -> Quad<S2, P2, O2, G2>
Maps every quad component with the given functions, one for each component.